@@ -35,7 +35,11 @@ func (attr *HCLAttribute) IsResolvable() bool {
 	if attr == nil {
 		return false
 	}
-	return attr.Value() != cty.NilVal
+	return attr.Value() != cty.NilVal && attr.Value().IsKnown()
+}
+
+func (attr *HCLAttribute) IsNotResolvable() bool {
+	return !attr.IsResolvable()
 }
 
 func (attr *HCLAttribute) Type() cty.Type {
@@ -477,7 +481,7 @@ func (attr *HCLAttribute) MapValue(mapKey string) cty.Value {
 			}
 		}
 	}
-	return cty.StringVal("")
+	return cty.NilVal
 }
 
 func (attr *HCLAttribute) LessThan(checkValue interface{}) bool {
