@@ -1,8 +1,7 @@
 package database
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -93,20 +92,16 @@ resource "azurerm_postgresql_server" "good_example" {
 					return
 				}
 
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not have %s set", resourceBlock.FullName(), attribute)),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not have %s set", resourceBlock.FullName(), attribute)
 				return
 			}
 
 			tlsMinimumAttr := resourceBlock.GetAttribute(attribute)
-			if !tlsMinimumAttr.Equals(requiredValue) {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has a value %s that is not %s", resourceBlock.FullName(), attribute, requiredValue)).
-						WithAttribute(tlsMinimumAttr),
-				)
+			if tlsMinimumAttr.NotEqual(requiredValue) {
+				set.AddResult().
+					WithDescription("Resource '%s' has a value %s that is not %s", resourceBlock.FullName(), attribute, requiredValue).
+					WithAttribute(tlsMinimumAttr)
 			}
 		},
 	})
