@@ -1,8 +1,7 @@
 package secrets
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/zclconf/go-cty/cty"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -72,10 +71,8 @@ resource "evil_corp" "virtual_machine" {
 			for _, attribute := range resourceBlock.GetAttributes() {
 				if attribute.Name() == "default" {
 					if attribute.Type() == cty.String && attribute.IsResolvable() {
-						set.Add(result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Variable '%s' includes a potentially sensitive default value.", resourceBlock.FullName())).
-							WithAttribute(attribute),
-						)
+						set.AddResult().WithDescription("Variable '%s' includes a potentially sensitive default value.", resourceBlock.FullName()).
+							WithAttribute(attribute)
 					}
 				}
 			}
